"""
This is a modle for print a list.
"""

def print_lol(the_list):
    
    """
    The function of print_lol is a test function.
    """
    for term in the_list:
        if(isinstance(term,list)):
            print_lol(term)
        else:
            print(term)



from setuptools import setup, find_packages
from distutils.core import setup
setup(
    name = 'zjy111',
    version = '1.0.0',
    py_modules = ['zjy111'],
    author = 'zjy_study',
    author_email = 'zjy_home@qq.com',
    url = 'https://test.pypi.org/legacy/',
    description = 'A simple printer of nested lists'    
    )
